@@ -7,7 +7,7 @@ use POSIX qw/ceil floor/;
 use Scalar::Util qw/blessed looks_like_number/;
 require Exporter;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 our @ISA = 'Exporter';
 our @EXPORT_OK = 'calc';
 our $ERROR;
@@ -292,13 +292,12 @@ sub evaluate {
 	
 	my @eval_stack;
 	foreach my $token (@$expr) {
-		if (blessed $token or $token =~ /^[\d.]/) {
-			push @eval_stack, $token;
-		} elsif (exists $self->_functions->{$token}) {
+		die "Undefined token in evaluate\n" unless defined $token;
+		if (exists $self->_functions->{$token}) {
 			my $function = $self->_functions->{$token};
 			my $num_args = $function->{args};
 			die "Malformed expression\n" if @eval_stack < $num_args;
-			my @args = $num_args > 0 ? splice @eval_stack, -$num_args : 0;
+			my @args = $num_args > 0 ? splice @eval_stack, -$num_args : ();
 			local $@;
 			my $result;
 			my $rc = eval { $result = $function->{code}(@args); 1 };
@@ -312,6 +311,8 @@ sub evaluate {
 				no warnings 'numeric';
 				push @eval_stack, 0+$result;
 			}
+		} elsif (looks_like_number $token) {
+			push @eval_stack, $token;
 		} else {
 			die "Invalid function or operator \"$token\"\n";
 		}
